@@ -27,7 +27,6 @@
 #include "matrix.h"
 #include <assert.h>
 #include <math.h>
-#include <stdio.h>
 #include <stdlib.h>
 
 
@@ -73,10 +72,11 @@ void zero(double **M, unsigned int n1, unsigned int n2)
 
 int isZero(double **M, unsigned int m, int sym)
 {
-  unsigned int i,j;
+  unsigned int i,j, upto;
   for(j=0; j<m; j++) {
-    if(sym) m = j+1;
-    for(i=0; i<m; i++)
+    upto = m;
+    if(sym) upto = j+1;
+    for(i=0; i<upto; i++)
       if(M[j][i] != 0.0) return 0;
   }
   return 1;
@@ -122,6 +122,19 @@ double ** new_zero_matrix(unsigned int n1, unsigned int n2)
 }
 
 
+/*
+ * same as new_imatrix, but zeros out the matrix
+ */
+
+int ** new_zero_imatrix(unsigned int n1, unsigned int n2)
+{
+  unsigned int i, j;
+  int **m = new_imatrix(n1, n2);
+  for(i=0; i<n1; i++) for(j=0; j<n2; j++) m[i][j] = 0;
+  return m;
+}
+
+
 /*
  * create a new n1 x n2 matrix which is allocated like
  * and n1*n2 array, but can be referenced as a 2-d array
@@ -242,6 +255,27 @@ double ** new_dup_matrix(double** M, unsigned int n1, unsigned int n2)
   return m;
 }
 
+
+/*
+ * create a new n1 x n2 matrix which is allocated like
+ * and n1*n2 array, and copy the of n1 x n2 M into it.
+ */
+
+int ** new_dup_imatrix(int** M, unsigned int n1, unsigned int n2)
+{
+  int **m;
+
+  if(n1 <= 0 || n2 <= 0) {
+    /* assert(M == NULL); */
+    return NULL;
+  }
+ 
+  m = new_imatrix(n1, n2);
+  dup_imatrix(m, M, n1, n2);
+  return m;
+}
+
+
 /*
  * create a new n1 x (n2-1) matrix which is allocated like
  * an n1*(n2-1) array, and copy M[n1][2:n2] into it.
@@ -256,9 +290,9 @@ double ** new_shift_matrix(double** M, unsigned int n1, unsigned int n2)
     return NULL;
   }
   m = new_matrix(n1, (n2-1));
-  /* printMatrix(M, n1, n2, stdout); */
+  /* printMatrix(M, n1, n2, mystdout); */
   for(i=0; i<n1; i++) for(j=0; j<(n2-1); j++) m[i][j] = M[i][j+1];
-  /* printMatrix(m, n1, (n2-1), stdout); */
+  /* printMatrix(m, n1, (n2-1), mystdout); */
   return m;
 }
 
@@ -276,6 +310,19 @@ void dup_matrix(double** M1, double **M2, unsigned int n1, unsigned int n2)
 }
 
 
+/*
+ * copy M2 to M1 for integer matrices
+ */
+
+void dup_imatrix(int** M1, int **M2, unsigned int n1, unsigned int n2)
+{
+  unsigned int i;
+  if(n1 == 0 || n2 == 0) return;
+  assert(M1 && M2);
+  for(i=0; i<n1; i++) dupiv(M1[i], M2[i], n2);
+}
+
+
 /*
  * swap the pointers of M2 to M1, and vice-versa
  * (tries to aviod dup_matrix when unnecessary)
@@ -337,6 +384,48 @@ double ** new_bigger_matrix(double** M, unsigned int n1, unsigned int n2,
 }
 
 
+/*
+ * create a bigger n1 x n2 matrix which is allocated like
+ * and n1*n2 array, and copy the of n1 x n2 M into it.
+ * deletes the old matrix -- integer version
+ */
+
+int ** new_bigger_imatrix(int** M, unsigned int n1, unsigned int n2, 
+			  unsigned int n1_new, unsigned int n2_new)
+{
+  int i;
+  int **m;
+  
+  assert(n1_new >= n1);
+  assert(n2_new >= n2);
+  
+  if(n1_new <= 0 || n2_new <= 0) {
+    assert(M == NULL);
+    return NULL;
+  }
+  
+  if(M == NULL) {
+    assert(n1 == 0 || n2 == 0);
+    return new_zero_imatrix(n1_new, n2_new);
+  }
+  
+  if(n2 == n2_new) {
+    m = (int**) malloc(sizeof(int*) * n1_new);
+    assert(m);
+    m[0] = realloc(M[0], sizeof(int) * n1_new * n2_new);
+    free(M);
+    assert(m[0]);
+    for(i=1; i<n1_new; i++) m[i] = m[i-1] + n2_new;
+    zeroiv(m[n1], (n1_new-n1)*n2_new);
+  } else {
+    m = new_zero_imatrix(n1_new, n2_new);
+    dup_imatrix(m, M, n1, n2);
+    delete_imatrix(M);
+  }
+  return m;
+}
+
+
 /*
  * create a new n1 x n2 matrix which is allocated like
  * and n1*n2 array, and copy the of n1 x n2 M into it.
@@ -1497,7 +1586,7 @@ void check_means(double *mean, double *q1, double *median,
   int replace = 0;
   for(i=0; i<n; i++) {
     if(mean[i] > q2[i] || mean[i] < q1[i]) {
-      myprintf(stdout, "replacing %g with (%g,%g,%g)\n", 
+      myprintf(mystdout, "replacing %g with (%g,%g,%g)\n", 
 	       mean[i], q1[i], median[i], q2[i]);
       mean[i] = median[i];
       replace++;
@@ -1506,7 +1595,7 @@ void check_means(double *mean, double *q1, double *median,
   
   /* let us know what happened */
   if(replace > 0) 
-    myprintf(stdout, "NOTICE: %d predictive means replaced with medians\n", 
+    myprintf(mystdout, "NOTICE: %d predictive means replaced with medians\n", 
 	     replace);
 }
 
@@ -1523,7 +1612,7 @@ unsigned int matrix_constrained(int *p, double **X, unsigned int n1,
 {
   unsigned int i,j, count;
   count = 0;
-  /* printRect(stderr, rect->d, rect->boundary); */
+  /* printRect(mystderr, rect->d, rect->boundary); */
   for(i=0; i<n1; i++) {
     p[i] = 1;
     for(j=0; j<n2; j++) {
@@ -1573,8 +1662,9 @@ Rect* new_rect(unsigned int d)
 
 Rect* new_drect(double **drect, int d)
 {
+  unsigned int i;
   Rect *rect = new_rect(d);
-  for(unsigned int i=0; i<d; i++) {
+  for(i=0; i<d; i++) {
     rect->boundary[0][i] = drect[0][i];
     rect->boundary[1][i] = drect[1][i];
     rect->opl[i] = GEQ;
@@ -1693,7 +1783,7 @@ void normalize(double **X, double **rect, int N, int d, double normscale)
 	X[j][i] = (X[j][i] - rect[0][i]) / norm;
       X[j][i] = normscale * X[j][i];
       /* if(!(X[j][i] >=0 && X[j][i] <= normscale))
-	myprintf(stdout, "X[%d][%d] = %g, normscale = %g\n", j, i, X[j][i], normscale);
+	myprintf(mystdout, "X[%d][%d] = %g, normscale = %g\n", j, i, X[j][i], normscale);
 	assert(X[j][i] >=0 && X[j][i] <= normscale); */
     }
   }
@@ -2009,6 +2099,21 @@ void add_vector(double a, double *v1, double b, double *v2, unsigned int n)
 }
 
 
+/*
+ * add two integer vectors of the same size 
+ * v1 = v1 + v2
+ */
+
+void add_ivector(int *v1, int *v2, unsigned int n)
+{
+  unsigned int i;
+  if(n == 0) return;
+  assert(n > 0);
+  assert(v1 && v2);
+  for(i=0; i<n; i++) v1[i] += v2[i];
+}
+
+
 /*
  * add_p_vector:
  *
